
#######################################################################
# THIS IS A SAMPLE TRAINING SHELL SCRIPT.  THESE PARAMETERIZATIONS
# WERE USED TO TRAIN TIGRSCAN ON TOXOPLASMA GONDII, WITH REASONABLY
# SATISFYING RESULTS.  YOU MIGHT TRY THESE AS DEFAULT PARAMETERIZATIONS
# TO BEGIN WITH.  SEE THE TRAINING MANUAL FOR STEPS THAT MUST BE
# PERFORMED BEFORE RUNNING THESE COMMANDS.
#######################################################################

#======================================================================
#                       TRAIN SIGNAL SENSORS
#======================================================================

tigrscan/train-signal.pl WAM start-codons0-100.fasta non-start-codons0-100.fasta start-codons0-100 1 ATG 5 3 13 0.99 1 80 0

tigrscan/train-signal.pl WAM stop-codons0-100.fasta non-stop-codons0-100.fasta stop-codons0-100 1 TAG 5 3 13 0.98 1 80 0

tigrscan/train-signal.pl WMM donors0-100.fasta non-donors0-100.fasta donors0-100 1 GT 5 2 12 0.98 1 80 0

tigrscan/train-signal.pl WMM acceptors0-100.fasta non-acceptors0-100.fasta acceptors0-100 1 AG 5 2 12 0.98 1 80 0

# MDD MODELS:
#train-mdd.pl <model-type> <pos.fasta> <neg.fasta> <filestem> <% train> 
#     <signal-type> <consensus-offset> <consensus-length> 
#     <context-window-length> <min-sens> <order> 
#     <min-sample-size> <max-depth> <WWAM-wnd-size> <use-pooled-model(0/1)>

tigrscan/train-mdd.pl WAM start-codons0-100.fasta non-start-codons0-100.fasta short-mdd-start-codons0-100 1 ATG 5 3 13 1.00 0 30 2 0 1

tigrscan/train-mdd.pl WAM stop-codons0-100.fasta non-stop-codons0-100.fasta short-mdd-stop-codons0-100 1 TAG 5 3 13 1.00 1 300 3 0 0 

tigrscan/train-mdd.pl WAM donors0-100.fasta non-donors0-100.fasta short-mdd-donors0-100 1 GT 5 2 12 1.00 0 300 1 0 1

tigrscan/train-mdd.pl WAM acceptors0-100.fasta non-acceptors0-100.fasta short-mdd-acceptors0-100 1 AG 5 2 12 1.00 1 300 2 0 0

#======================================================================
#                      TRAIN CONTENT SENSORS
#======================================================================

tigrscan/train-content-sensor -o 5 -s 80 3PIMM initial-exons0-100.fasta non-initial-exons0-100.fasta initial-exons0-100 1.0 INITIAL-EXON -g

tigrscan/train-content-sensor -o 5 -s 80 3PIMM final-exons0-100.fasta non-final-exons0-100.fasta final-exons0-100 1.0 FINAL-EXON -g

tigrscan/train-content-sensor -o 5 -s 80 3PIMM internal-exons0-100.fasta non-internal-exons0-100.fasta internal-exons0-100 1.0 INTERNAL-EXON -g

tigrscan/train-content-sensor -o 5 -s 80 3PIMM single-exons0-100.fasta non-single-exons0-100.fasta single-exons0-100 1.0 SINGLE-EXON -g

tigrscan/train-content-sensor -o 5 -s 80 IMM introns0-100.fasta non-introns0-100.fasta introns0-100 1.0 INTRON -g

tigrscan/train-content-sensor -o 0 -s 80 IMM intergenic0-100.fasta non-intergenic0-100.fasta intergenic0-100 1.0 INTERGENIC -g

tigrscan/train-content-sensor -o 1 -s 80 IMM five-prime-UTR0-100.fasta three-prime-UTR0-100.fasta five-prime-UTR0-100 1.0 FIVE-PRIME-UTR -g

tigrscan/train-content-sensor -o 1 -s 80 IMM three-prime-UTR0-100.fasta five-prime-UTR0-100.fasta three-prime-UTR0-100 1.0 THREE-PRIME-UTR -g

# POOLED EXONS:
tigrscan/train-content-sensor -o 5 -s 80 3P pooled-exons0-100.fasta non-initial-exons0-100.fasta pooled-initial-exons0-100 1.0 INITIAL-EXON -g

cp pooled-initial-exons0-100.model pooled-internal-exons0-100.model
sub pooled-internal-exons0-100.model INITIAL-EXON INTERNAL-EXON

cp pooled-initial-exons0-100.model pooled-final-exons0-100.model
sub pooled-final-exons0-100.model INITIAL-EXON FINAL-EXON

cp pooled-initial-exons0-100.model pooled-single-exons0-100.model
sub pooled-single-exons0-100.model INITIAL-EXON SINGLE-EXON

# INTERPOLATED MODELS (IMM'S)
tigrscan/train-content-sensor -o 5 -s 50 3PIMM initial-exons0-100.fasta non-initial-exons0-100.fasta imm-initial-exons0-100 1.0 INITIAL-EXON -g

tigrscan/train-content-sensor -o 5 -s 50 3PIMM final-exons0-100.fasta non-final-exons0-100.fasta imm-final-exons0-100 1.0 FINAL-EXON -g

tigrscan/train-content-sensor -o 5 -s 50 3PIMM internal-exons0-100.fasta non-internal-exons0-100.fasta imm-internal-exons0-100 1.0 INTERNAL-EXON -g

tigrscan/train-content-sensor -o 5 -s 50 3PIMM single-exons0-100.fasta non-single-exons0-100.fasta imm-single-exons0-100 1.0 SINGLE-EXON -g

tigrscan/train-content-sensor -o 5 -s 50 IMM introns0-100.fasta non-introns0-100.fasta imm-introns0-100 1.0 INTRON -g

tigrscan/train-content-sensor -o 0 -s 50 IMM intergenic0-100.fasta non-intergenic0-100.fasta imm-intergenic0-100 1.0 INTERGENIC -g

tigrscan/train-content-sensor -o 2 -s 50 IMM five-prime-UTR0-100.fasta three-prime-UTR0-100.fasta imm-five-prime-UTR0-100 1.0 FIVE-PRIME-UTR -g

tigrscan/train-content-sensor -o 2 -s 50 IMM three-prime-UTR0-100.fasta five-prime-UTR0-100.fasta imm-three-prime-UTR0-100 1.0 THREE-PRIME-UTR -g

#======================================================================
#                        GET DISTRIBUTIONS
#======================================================================

tigrscan/get-distributions.pl . 5 2

tigrscan/get-trans-distr.pl iso0-100.gff > tigrscan.trans



